RewoDemo class

Starts the built-in demo API bundled with the Rewo framework repo.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bootstrap({int? port, ServerEngine? engine, String envFile = '.env'}) Future<Rewo>
Configures modules and returns the app before listening (for tests/custom startup).
start({int? port, ServerEngine? engine, String envFile = '.env'}) Future<Rewo>
Configures modules and begins serving HTTP requests.