Task class

Constructors

Task({required String id, required String title, required String description, required bool done, required DateTime createdAt})

Properties

createdAt DateTime
final
description String
final
done bool
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

copyWith({bool? done}) Task
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited