TaskService class
Constructors
-
TaskService(InMemoryRepository<
Task, String> _repo)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
all(
) → Future< List< Task> > -
create(
CreateTaskRequest req) → Future< Task> -
delete(
String id) → Future< bool> -
find(
String id) → Future< Task> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toggle(
String id) → Future< Task> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited