UserController class

Inheritance

Constructors

UserController(UserService _users)

Properties

basePath String
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adminStats(RequestContext ctx) Future<Map<String, dynamic>>
create(RequestContext ctx) Future<Map<String, dynamic>>
get(RequestContext ctx) Future<Map<String, dynamic>>
list(RequestContext ctx) Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes(RouteRegistrar r) → void
override
remove(RequestContext ctx) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited