UserService class

Constructors

UserService(InMemoryRepository<User, String> _repo, EventBus _events, TransactionManager _transactions)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFromRequest(CreateUserRequest req) Future<User>
delete(String id) Future<bool>
findAll() Future<List<User>>
findById(String id) Future<User>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited