AuthModule class

Registers login, logout, and profile routes for the demo app.

Implemented types

Constructors

AuthModule()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Rewo app) → void
Register routes, services, and event listeners on the app.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited