CreateUserRequest class

Payload accepted by POST /api/users.

Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

CreateUserRequest({required String email, required String name})
Creates a request with email and name.
const
CreateUserRequest.fromJson(Map<String, dynamic> json)
Parses JSON into a CreateUserRequest.
factory

Properties

email String
User email address.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited