InMemoryRepository<T, ID> class

Implemented types

Constructors

InMemoryRepository({required ID getId(T item), Map<ID, T>? items})

Properties

getId → ID Function(T item)
final
hashCode int
The hash code for this object.
no setterinherited
items Map<ID, T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteById(ID id) Future<bool>
override
findAll() Future<List<T>>
override
findById(ID id) Future<T?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save(T entity) Future<T>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited