IsolatePool class

Shared isolate pool — reuses workers instead of spawning per task.

Constructors

IsolatePool({int? workers})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run<M, R>(ComputeCallback<M, R> callback, M message) Future<R>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited