Rewo class

Constructors

Rewo({AppConfig? config, ServerEngine? engine, SecurityContext? securityContext})

Properties

config AppConfig
final
container ServiceContainer
final
engine ServerEngine
final
events EventBus
final
hashCode int
The hash code for this object.
no setterinherited
health HealthCheck
final
isolates IsolatePool
no setter
metrics Metrics
final
openApi OpenApiGenerator
final
routeTable RouteTable
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduler Scheduler
final
transactions TransactionManager
final
webSocketRouteTable WebSocketRouteTable
no setter

Methods

close() Future<void>
compileRoutesForTest() → void
delete(String path, RouteHandler handler, {List<MiddlewareHandler>? middleware, int statusCode = 200}) → void
factory<T>(T creator(ServiceContainer c)) → void
get(String path, RouteHandler handler, {List<MiddlewareHandler>? middleware, int statusCode = 200}) → void
lazy<T>(T creator(ServiceContainer c)) → void
listen() Future<void>
mount(RestController controller) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path, RouteHandler handler, {List<MiddlewareHandler>? middleware, int statusCode = 200}) → void
post(String path, RouteHandler handler, {List<MiddlewareHandler>? middleware, int statusCode = 200}) → void
put(String path, RouteHandler handler, {List<MiddlewareHandler>? middleware, int statusCode = 200}) → void
schedule(int intervalSeconds, FutureOr<void> task()) → void
singleton<T>(T instance) → void
toString() String
A string representation of this object.
inherited
use(Middleware middleware) → void
useDefaults() → void
useOpsEndpoints() → void
useStaticFiles(String directory, {String prefix = '/public'}) → void
webSocket(String path, WebSocketConnectHandler onConnect, {List<MiddlewareHandler>? middleware}) → void
Registers a WebSocket endpoint (native + shelf engines).

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

run(ConfigureCallback configure, {AppConfig? config, ServerEngine? engine, String envFile = '.env'}) Future<Rewo>