RewoModule class abstract
A pluggable API module. Create one per feature, register in moduleRegistry.
- Implementers
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
Rewo app) → void - Register routes, services, and event listeners on the app.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited