CreateTaskRequest class

Payload accepted by POST /api/tasks.

Annotations
  • @JsonSerializable.new()

Constructors

CreateTaskRequest({required String title, String description = ''})
Creates a request with title and optional description.
CreateTaskRequest.fromJson(Map<String, dynamic> json)
Parses JSON into a CreateTaskRequest.
factory

Properties

description String
Optional longer description.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
Short task title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this request to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited