TaskController class

REST controller for /api/tasks.

Inheritance

Constructors

TaskController(TaskService _tasks)
Creates a controller backed by tasks.

Properties

basePath String
URL prefix for all routes registered by this controller.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(RequestContext ctx) Future<Map<String, dynamic>>
getOne(RequestContext ctx) Future<Map<String, dynamic>>
list(RequestContext ctx) Future<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes(RouteRegistrar r) → void
Register HTTP routes on registrar.
override
remove(RequestContext ctx) Future<Map<String, dynamic>>
toggle(RequestContext ctx) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited