$GeneratedUserControllerRoutes mixin

Superclass constraints
Mixin applications

Properties

basePath String
URL prefix for all routes registered by this controller.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes(RouteRegistrar registrar) → void
Register HTTP routes on registrar.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited