User class

Demo user entity stored in memory.

Constructors

User({required String id, required String email, required String name})
Creates a user with id, email, and name.

Properties

email String
Login email address.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier.
final
name String
Display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this user to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited