UserController class

REST controller for /api/users.

Inheritance

Constructors

UserController(UserService _users)
Creates a controller backed by users.

Properties

basePath String
URL prefix for all routes registered by this controller.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

adminStats(RequestContext ctx) Future<Map<String, dynamic>>
create(RequestContext ctx) Future<Map<String, dynamic>>
get(RequestContext ctx) Future<Map<String, dynamic>>
list(RequestContext ctx) Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRoutes(RouteRegistrar r) → void
Register HTTP routes on registrar.
override
remove(RequestContext ctx) Future<Map<String, dynamic>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited